pub struct VersionCarrier {
pub version: u32,
pub services: u64,
pub timestamp: u64,
pub receiver: Address,
pub sender: Address,
pub nonce: u64,
pub user_agent: String,
pub start_height: u32,
pub relay: bool,
}Fields
version: u32The P2P network protocol version
services: u64A bitmask describing the services supported by this node
timestamp: u64The time at which the version message was sent
receiver: AddressThe network address of the peer receiving the message
sender: AddressThe network address of the peer sending the message
nonce: u64A random nonce used to detect loops in the network
user_agent: StringA string describing the peer’s software
start_height: u32The height of the maximum-work blockchain that the peer is aware of
relay: boolWhether the receiving peer should relay messages to the sender; used if the sender is bandwidth-limited and would like to support bloom filtering. Defaults to true.